@@ -110,12 +110,6 @@ class HMFInputBase(FormView):
     success_url = '../../hmf_image_page/'
     template_name = 'hmfform.html'
 
-    def get_success_url(self):
-        if not self.mf_error and not self.dist_error and not self.merge_error:
-            return '../../hmf_image_page/'
-        else:
-            return '../../error_page/'
-
     #Define what to do if the form is valid.
     def form_valid(self, form):
         # log = logging.getLogger(__name__)
@@ -240,8 +234,6 @@ class HMFInputBase(FormView):
             self.request.session['input_data'] = self.request.session['input_data'] + [form.cleaned_data]
             self.request.session['warnings'].update(warnings)
             self.request.session['extra_plots'] = list(set(form.cleaned_data['extra_plots'] + self.request.session['extra_plots']))
-            self.merge_error = False
-
         elif self.request.path.endswith('create/'):
             self.request.session["mass_data"] = mass_data
             self.request.session["k_data"] = k_data
